@@ -1,8 +1,31 @@
-# ggproto() is probably to messy to be able to use it as a reverse constructor,
-# so we just construct if we find the
+#' @export
+#' @rdname other-opts
+opts_ggproto <- function(constructor = c("default", "next", "environment"), ...) {
+  .cstr_options("ggproto", constructor = constructor[[1]], ...)
+}
 
 #' @export
-.cstr_construct.ggproto <- function(x, ggproto.ignore_draw_key = FALSE, ...) {
+#' @method .cstr_construct ggproto
+.cstr_construct.ggproto <- function(x, ...) {
+  opts <- list(...)$opts$ggproto %||% opts_ggproto()
+  if (is_corrupted_ggproto(x) || opts$constructor == "next") return(NextMethod())
+  UseMethod(".cstr_construct.ggproto", structure(NA, class = opts$constructor))
+}
+
+is_corrupted_ggproto <- function(x) {
+  # TODO
+  FALSE
+}
+
+#' @export
+#' @method .cstr_construct.ggproto environment
+.cstr_construct.ggproto.environment <- function(x, ...) {
+  .cstr_construct.environment(x, ...)
+}
+
+#' @export
+#' @method .cstr_construct.ggproto default
+.cstr_construct.ggproto.default <- function(x, ..., ggproto.ignore_draw_key = FALSE) {
   if (ggproto.ignore_draw_key) {
     x <- as.list(x)
     x$draw_key <- NULL
