@@ -1,5 +1,3 @@
-constructors$weakref <- new.env()
-
 #' Constructive options for the class `weakref`
 #'
 #' These options will be used on objects of type `weakref`. `weakref` objects
@@ -11,26 +9,24 @@ constructors$weakref <- new.env()
 #' @return An object of class <constructive_options/constructive_options_array>
 #' @export
 opts_weakref <- function(constructor = c("new_weakref"), ...) {
-  .cstr_combine_errors(
-    constructor <- .cstr_match_constructor(constructor, "weakref"),
-    check_dots_empty()
-  )
-  .cstr_options("weakref", constructor = constructor)
+  .cstr_options("weakref", constructor = constructor[[1]], ...)
 }
 
 #' @export
+#' @method .cstr_construct weakref
 .cstr_construct.weakref <- function(x, ...) {
-  opts <- .cstr_fetch_opts("weakref", ...)
+  opts <- list(...)$opts$weakref %||% opts_weakref()
   if (is_corrupted_weakref(x) || opts$constructor == "next") return(NextMethod())
-  constructor <- constructors$weakref[[opts$constructor]]
-  constructor(x, ...)
+  UseMethod(".cstr_construct.weakref", structure(NA, class = opts$constructor))
 }
 
 is_corrupted_weakref <- function(x) {
   !rlang::is_weakref(x)
 }
 
-constructors$weakref$new_weakref <- function(x, ...) {
+#' @export
+#' @method .cstr_construct.weakref new_weakref
+.cstr_construct.weakref.new_weakref <- function(x, ...) {
   args <- list(rlang::wref_key(x))
   # assigned this way so no element is added if NULL
   args$value <- rlang::wref_value(x)
@@ -39,6 +35,6 @@ constructors$weakref$new_weakref <- function(x, ...) {
 }
 
 repair_attributes_weakref <- function(x, code, ...) {
-  # FIXME do these need any reparation ?
+  # FIXME do these need any repair ?
   code
 }
