@@ -10,17 +10,11 @@
 extern SEXP external_pointer(SEXP);
 extern SEXP external_pointer_address(SEXP);
 extern SEXP objectFromAddress(SEXP);
-extern SEXP is_promise(SEXP, SEXP);
-extern SEXP promise_code(SEXP, SEXP);
-extern SEXP promise_env(SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
   {"external_pointer",         (DL_FUNC) &external_pointer,         1},
   {"external_pointer_address", (DL_FUNC) &external_pointer_address, 1},
   {"objectFromAddress",        (DL_FUNC) &objectFromAddress,        1},
-  {"is_promise",               (DL_FUNC) &is_promise,               2},
-  {"promise_code",             (DL_FUNC) &promise_code,             2},
-  {"promise_env",              (DL_FUNC) &promise_env,              2},
   {NULL, NULL, 0}
 };
 
@@ -32,7 +26,12 @@ void R_init_constructive(DllInfo *dll)
 
 // Thanks to Randi Lai: https://github.com/randy3k/xptr/
 SEXP external_pointer(SEXP p) {
-  return R_MakeExternalPtr((void*) strtol(CHAR(STRING_PTR(p)[0]), NULL, 0), NULL, NULL);
+  if (TYPEOF(p) != STRSXP || LENGTH(p) < 1) {
+    error("Input must be a character vector of at least length 1");
+  }
+  const char* str = CHAR(STRING_ELT(p, 0));
+  void* ptr = (void*) strtol(str, NULL, 0);
+  return R_MakeExternalPtr(ptr, R_NilValue, R_NilValue);
 }
 
 SEXP external_pointer_address(SEXP s) {
@@ -58,21 +57,4 @@ SEXP objectFromAddress(SEXP a) {
   return result;
 }
 
-// adapted from pryr
-SEXP is_promise(SEXP name, SEXP env) {
-  SEXP result = PROTECT(allocVector(LGLSXP, 1)); // Create a logical vector of length 1
-  SEXP object = Rf_findVar(name, env);
-  LOGICAL(result)[0] = TYPEOF(object) == PROMSXP && PRVALUE(object) == R_UnboundValue;
-  UNPROTECT(1);
-  return result;
-}
 
-SEXP promise_code(SEXP name, SEXP env) {
-  SEXP object = Rf_findVar(name, env);
-  return PRCODE(object);
-}
-
-SEXP promise_env(SEXP name, SEXP env) {
-  SEXP object = Rf_findVar(name, env);
-  return PRENV(object);
-}
