@@ -24,9 +24,26 @@ test_that("noquote is supported", {
 })
 
 test_that("compare_options", {
-  expect_pipe_snapshot({
+  expect_snapshot({
     construct(evalq(x ~ y, asNamespace("stats")))
     construct(evalq(x ~ y, asNamespace("stats")), opts_formula(environment = FALSE))
     construct(evalq(x ~ y, asNamespace("stats")), opts_formula(environment = FALSE), compare = compare_options(ignore_formula_env = TRUE))
   })
 })
+
+test_that("backslash and emojis in names work", {
+  expect_snapshot({
+    construct(c("\\" = "\\"))
+  })
+})
+
+
+test_that("backslash and emojis in names work for R >= 4.1", {
+  # Due to bypass.R
+  skip_if(base::`<`(getRversion(), "4.1"))
+
+  expect_snapshot({
+    construct(c("\\🐶" = "\\"), unicode_representation = "unicode")
+    construct(c("\\🐶" = "\\"))
+  })
+})
