@@ -45,11 +45,41 @@ test_that("data.frame", {
       class = "data.frame"
     ))
     construct(data.frame(a = "two words"), constructive::opts_data.frame("read.table"))
-    # column named with a problematic name
-    constructive::construct(as.data.frame(list(row.names = 1:2)))
     construct(data.frame(row.names = c("a", "b")))
   })
 })
 
-# -------------------------------------------------------------------------
+test_that("recycle in data frames", {
+  expect_snapshot({
+    construct(data.frame(a = 1:2, b = c(1, 1)))
+    construct(data.frame(a = c(1, 1), b = c(1, 1)))
+    construct(data.frame(a = 1:2, b = factor(c("a", "a"))))
+    construct(data.frame(a = 1:2, b = as.Date(c("2000-01-01", "2000-01-01"))))
+  })
+})
 
+test_that("duplicate names in data frames", {
+  expect_snapshot({
+    construct(data.frame(a = 1, a =2, check.names = FALSE))
+  })
+})
+
+test_that("non standard names in data frames", {
+  expect_snapshot({
+    construct(structure(data.frame(1), names = NULL))
+    construct(structure(data.frame(1), names = ""))
+    construct(structure(data.frame(1), names = NA))
+    construct(structure(data.frame(1), names = "row.names"))
+    construct(structure(data.frame(1), names = "check.rows"))
+    construct(structure(data.frame(1), names = "check.names"))
+    construct(structure(data.frame(1), names = "fix.empty.names"))
+    construct(structure(data.frame(1), names = "stringsAsFactors"))
+    construct(structure(data.frame(1, 2), names = c("a", "")))
+    construct(structure(data.frame(1, 2), names = c("a", NA)))
+    construct(structure(data.frame(1, 2), names = c("a", "row.names")))
+    construct(structure(data.frame(1, 2), names = c("a", "check.rows")))
+    construct(structure(data.frame(1, 2), names = c("a", "check.names")))
+    construct(structure(data.frame(1, 2), names = c("a", "fix.empty.names")))
+    construct(structure(data.frame(1, 2), names = c("a", "stringsAsFactors")))
+  })
+})
